==> qtjambi-location-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiLocation/QGeoServiceProviderFactory_shell.h <==
#ifndef QGEOSERVICEPROVIDERFACTORY_IMPL_SHELL_H
#define QGEOSERVICEPROVIDERFACTORY_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtLocation/qgeoserviceproviderfactory.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qstring.h>
#include <QtLocation/qgeocodingmanagerengine.h>
#include <QtLocation/qgeoroutingmanagerengine.h>
#include <QtLocation/qplacemanagerengine.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QGeoServiceProviderFactory_shell : public QGeoServiceProviderFactory, public QtJambiShellInterface
{
public:
    QGeoServiceProviderFactory_shell();
    ~QGeoServiceProviderFactory_shell() override;

    QGeoCodingManagerEngine* createGeocodingManagerEngine(const QMap<QString, QVariant>& parameters0, QGeoServiceProvider::Error* error1, QString* errorString2) const override;
    QPlaceManagerEngine* createPlaceManagerEngine(const QMap<QString, QVariant>& parameters0, QGeoServiceProvider::Error* error1, QString* errorString2) const override;
    QGeoRoutingManagerEngine* createRoutingManagerEngine(const QMap<QString, QVariant>& parameters0, QGeoServiceProvider::Error* error1, QString* errorString2) const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGeoServiceProviderFactory_access : public QGeoServiceProviderFactory
{
    jobject __qt_createGeocodingManagerEngine_cref_QMap_QGeoServiceProvider_Error_ptr_QString_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject parameters0) const;
    jobject __qt_createPlaceManagerEngine_cref_QMap_QGeoServiceProvider_Error_ptr_QString_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject parameters0) const;
    jobject __qt_createRoutingManagerEngine_cref_QMap_QGeoServiceProvider_Error_ptr_QString_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject parameters0) const;
};

#endif // QGEOSERVICEPROVIDERFACTORY_IMPL_SHELL_H

==> qtjambi-location-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiLocation/QGeoServiceProviderFactory_shell.h <==
#ifndef QGEOSERVICEPROVIDERFACTORY_IMPL_SHELL_H
#define QGEOSERVICEPROVIDERFACTORY_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtLocation/qgeoserviceproviderfactory.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qstring.h>
#include <QtLocation/qgeocodingmanagerengine.h>
#include <QtLocation/qgeoroutingmanagerengine.h>
#include <QtLocation/qplacemanagerengine.h>
#include <QtQml/qqmlengine.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QGeoServiceProviderFactory_shell : public QGeoServiceProviderFactory, public QtJambiShellInterface
{
public:
    QGeoServiceProviderFactory_shell();
    ~QGeoServiceProviderFactory_shell() override;

    QGeoCodingManagerEngine* createGeocodingManagerEngine(const QMap<QString, QVariant>& parameters0, QGeoServiceProvider::Error* error1, QString* errorString2) const override;
    QPlaceManagerEngine* createPlaceManagerEngine(const QMap<QString, QVariant>& parameters0, QGeoServiceProvider::Error* error1, QString* errorString2) const override;
    QGeoRoutingManagerEngine* createRoutingManagerEngine(const QMap<QString, QVariant>& parameters0, QGeoServiceProvider::Error* error1, QString* errorString2) const override;
    void setQmlEngine(QQmlEngine* engine0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGeoServiceProviderFactory_access : public QGeoServiceProviderFactory
{
    jobject __qt_createGeocodingManagerEngine_cref_QMap_QGeoServiceProvider_Error_ptr_QString_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject parameters0) const;
    jobject __qt_createPlaceManagerEngine_cref_QMap_QGeoServiceProvider_Error_ptr_QString_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject parameters0) const;
    jobject __qt_createRoutingManagerEngine_cref_QMap_QGeoServiceProvider_Error_ptr_QString_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject parameters0) const;
    void __qt_setQmlEngine_QQmlEngine_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID engine0);
};

#endif // QGEOSERVICEPROVIDERFACTORY_IMPL_SHELL_H
